@@ -17,21 +17,28 @@ safeDeparse <- function(expr){
 #' @return An object of mode "\code{\link[base]{call}}".
 #' @author Fabian Scheipl
 #' @seealso \code{\link[base]{match.call}}
-expand.call <-
-        function(definition=NULL, call=sys.call(sys.parent(1)), expand.dots = TRUE)
-{
+expand.call <- function(definition=NULL, call=sys.call(sys.parent(1)),
+  expand.dots = TRUE)
+  {
     call <- match.call(definition, call, expand.dots)
     #given args:
     ans <- as.list(call)
-
-    #possible args:
-    frmls <- formals(safeDeparse(ans[[1]]))
+    this_function <- safeDeparse(ans[[1]])
+    # rm namespace operators so that function finding works (mlr-org/mlr/#1559)
+    if (grepl(":", this_function)) {
+      this_function <- gsub("(^[^:]+:+)(.+$)", "\\2", this_function)
+      if (!exists(this_function)) {
+        warning("expand.call couldn't find ", this_function,
+          " and returned unchanged call:\n <", call, ">")
+        return(call)
+      }
+    }
+    frmls <- formals(this_function)
     #remove formal args with no presets:
     frmls <- frmls[!sapply(frmls, is.symbol)]
-
     add <- which(!(names(frmls) %in% names(ans)))
     return(as.call(c(ans, frmls[add])))
-}
+  }
 
 
 
@@ -114,9 +121,9 @@ getShrtlbls <- function(object){
 #' Simulates example data for \code{\link{pffr}} from a variety of terms.
 #' Scenario "all" generates data from a complex multivariate model \deqn{Y_i(t)
 #' = \mu(t) + \int X_{1i}(s)\beta_1(s,t)ds + xlin \beta_3(t) + f(xte1, xte2) +
-#' f(xsmoo, t) + \beta_4 xconst + \epsilon_i(t)}. Scenarios "int", "ff", "lin",
-#' "te", "smoo", "const" generate data from simpler models containing only the
-#' respective term(s)  in the model equation given above. Specifiying a
+#' f(xsmoo, t) + \beta_4 xconst + f(xfactor, t) +  \epsilon_i(t)}. Scenarios "int", "ff", "lin",
+#' "te", "smoo", "const", "factor", generate data from simpler models containing only the
+#' respective term(s)  in the model equation given above. Specifying a
 #' vector-valued scenario will generate data from a combination of the
 #' respective terms. Sparse/irregular response trajectories can be generated by
 #' setting \code{propmissing} to something greater than 0 (and smaller than 1).
@@ -196,7 +203,7 @@ pffrSim <- function(
        range <- outer(s, t, limits)
        beta1.st  <- beta1.st * range
     }
-    etaTerms$X1 <- LX1%*%beta1.st
+    etaTerms$X1 <- LX1 %*% beta1.st
 
 #     data$X2 <- I(t(replicate(n, rf(s))))
 #     LX2 <- L*data$X2
@@ -205,12 +212,22 @@ pffrSim <- function(
 
     #scalar covariates
     data$xlin <- I(rnorm(n))
-    beta.t <- matrix(scale(-dnorm(4*(t-.2))), nrow=n, ncol=nygrid, byrow=T)
-    etaTerms$xlin <- data$xlin*beta.t
+    beta.t <- matrix(scale(-dnorm(4 * (t - .2))), nrow = n, ncol = nygrid,
+      byrow = T)
+    etaTerms$xlin <- data$xlin * beta.t
 
     data$xsmoo <- I(rnorm(n))
     etaTerms$xsmoo <- outer(drop(scale(cos(data$xsmoo))), (t-.5), "*")
 
+    data$xfactor <- sample(gl(3, n/3), replace = TRUE)
+    etaTerms$xfactor <-  2* as.numeric(data$xfactor) +
+      sin(2 * outer(as.numeric(data$xfactor), t))
+    if ("2factor" %in% scenario) {
+      data$x2factor <- sample(gl(3, n/3), replace = TRUE)
+      etaTerms$x2factor <-  2 * as.numeric(data$x2factor) +
+        cos(2 * outer(as.numeric(data$x2factor), t))
+    }
+
     data$xte1 <- I(rnorm(n))
     data$xte2 <- I(rnorm(n))
     etaTerms$xte <- matrix(drop(scale(-data$xte1*data$xte2^2)),
@@ -230,9 +247,11 @@ pffrSim <- function(
                            "lin" = etaTerms$xlin,
                            "smoo" = etaTerms$xsmoo,
                            "te" = etaTerms$xte,
-                           "const" = etaTerms$xconst)
+                           "const" = etaTerms$xconst,
+                           "factor" = etaTerms$xfactor)
     } else {
-      stopifnot(all(scenario %in% c("int" ,"ff", "lin", "smoo", "te", "const")))
+      stopifnot(all(scenario %in% c("int" ,"ff", "lin", "smoo", "te", "const",
+        "factor", "2factor")))
       eta <- 0*mu.t
       if("int" %in% scenario) eta <- eta + mu.t
       if("ff" %in% scenario) eta <- eta + etaTerms$X1 #+ etaTerms$X2
@@ -240,6 +259,8 @@ pffrSim <- function(
       if("smoo" %in% scenario) eta <- eta + etaTerms$xsmoo
       if("te" %in% scenario) eta <- eta + etaTerms$xte
       if("const" %in% scenario) eta <- eta + etaTerms$xconst
+      if("factor" %in% scenario) eta <- eta + etaTerms$xfactor
+      if("2factor" %in% scenario) eta <- eta + etaTerms$x2factor
     }
 
 
@@ -283,7 +304,7 @@ pffrSim <- function(
 #' original idea, implementation follows that in the 'ts' and 'cs' constructors
 #' (see \code{\link[mgcv]{smooth.terms}}).
 #'
-#' @param object see \code{\link[mgcv]{smooth.construct}}. The shrinkage factor can be speficied via \code{object$xt$shrink}
+#' @param object see \code{\link[mgcv]{smooth.construct}}. The shrinkage factor can be specified via \code{object$xt$shrink}
 #' @param data see \code{\link[mgcv]{smooth.construct}}.
 #' @param knots see \code{\link[mgcv]{smooth.construct}}.
 #'
